==> filemv0.372.0.2.zip: source/keyboard.cpp <==

#ifndef STRICT
    #define STRICT
#endif
#include "defextern.h"
#include <windows.h>
#include <windowsx.h>
#include <commctrl.h>
#include "resource.h"
#include "dir.h"
#include "myfilemv.h"
#include "initial.h"
#include "keyboard.h"
#include "main.h"


#include "mainmsg.h"



WORD keyfnc(WORD key)
{
	WORD al =0;
	if (GetKeyState(VK_SHIFT) < 0) al += kSHIFT;
	if (GetKeyState(VK_CONTROL) < 0) al += kCONTROL;
	if (GetKeyState(VK_MENU) < 0) al += kALT;
	return transkey( key + al );
}



#define kCASE(a,b) case a :{ mainMsg(b) ; break; }


// tH[JXXgɂƂ̃L[

void ListKeyFunc(HWND hWnd, UINT msg, WPARAM wp, LPARAM lp,int tab)
{
    static LPNMHDR lpnmhdr;
    static LV_KEYDOWN *lvkeydown;
	dirw *NDir =GetNDir();
    lpnmhdr = (LPNMHDR)lp;
	lvkeydown =(LV_KEYDOWN*)lp;//EN_UPDATE
	WORD key =keyfnc(lvkeydown->wVKey);

	// R}h
	if(key >= '1'+kALT && key <= '9' +kALT)
		mainMsg( IDM_CMD_BASE + (key - ('1'+kALT) +1 ) );
	switch (key)
	{
	case VK_ESCAPE :
		{
			SetFocus(hEdit);
			return ;
		}
	case VK_RETURN +kSHIFT: 
		mainMsg( IDM_EDIT );
		break;
	case VK_RETURN: 
		lpnmhdr->code =NM_DBLCLK;
		SendMessage( hWnd, msg, wp, lp);
		break;
	case VK_F11: 
		mainMsg( IDM_WINDOW_MAX);
		break;
	case VK_F11 +kSHIFT: 
		mainMsg( IDM_WINDOW_INI);
		break;
	case VK_TAB: 
		if(tab ==tab_l ) SetFocus(hList);
		if(tab ==tab_r ) SetFocus(hListL);
		break;
	case VK_BACK:
		mainMsg( IDM_UPDIRLOCAL);
		break;
	case VK_DELETE:
		mainMsg( IDM_DELFILELOCAL);
		break;
	case VK_DELETE +kSHIFT:
		mainMsg( IDM_DEL_MENU);
		break;
	case VK_LEFT +kSHIFT:
		mainMsg( IDM_HIS_BACKWARD);
		break;
	case VK_RIGHT +kSHIFT:
		mainMsg( IDM_HIS_FORWARD);
		break;
	case VK_LEFT +kALT:
		break;
	case VK_RIGHT +kALT:
		break;
	case 'A' +kCONTROL +kALT:
		NDir->cd("a:\\");
		reloadtab();
		break;
	case 'B' +kCONTROL +kALT:
		NDir->cd("b:\\");
		reloadtab();
		break;
	case 'C' +kCONTROL +kALT:
		NDir->cd("c:\\");
		reloadtab();
		break;
	case 'D' +kCONTROL +kALT:
		NDir->cd("d:\\");
		reloadtab();
		break;
	case 'E' +kCONTROL +kALT:
		NDir->cd("e:\\");
		reloadtab();
		break;
	case 'F' +kCONTROL +kALT:
		NDir->cd("f:\\");
		reloadtab();
		break;
	case 'G' +kCONTROL +kALT:
		NDir->cd("g:\\");
		reloadtab();
		break;
	case 'H' +kCONTROL +kALT:
		NDir->cd("h:\\");
		reloadtab();
		break;
	case 'I' +kCONTROL +kALT:
		NDir->cd("i:\\");
		reloadtab();
		break;
	case 'J' +kCONTROL +kALT:
		NDir->cd("j:\\");
		reloadtab();
		break;
	case 'K' +kCONTROL +kALT:
		NDir->cd("k:\\");
		reloadtab();
		break;
	case 'L' +kCONTROL +kALT:
		NDir->cd("l:\\");
		reloadtab();
		break;
	case 'M' +kCONTROL +kALT:
		NDir->cd("m:\\");
		reloadtab();
		break;
	case 'N' +kCONTROL +kALT:
		NDir->cd("n:\\");
		reloadtab();
		break;
	case 'O' +kCONTROL +kALT:
		NDir->cd("o:\\");
		reloadtab();
		break;
	case 'P' +kCONTROL +kALT:
		NDir->cd("p:\\");
		reloadtab();
		break;
	case 'Q' +kCONTROL +kALT:
		NDir->cd("q:\\");
		reloadtab();
		break;
	case 'R' +kCONTROL +kALT:
		NDir->cd("r:\\");
		reloadtab();
		break;
	case 'S' +kCONTROL +kALT:
		NDir->cd("s:\\");
		reloadtab();
		break;
	case 'T' +kCONTROL +kALT:
		NDir->cd("t:\\");
		reloadtab();
		break;
	case 'U' +kCONTROL +kALT:
		NDir->cd("u:\\");
		reloadtab();
		break;
	case 'V' +kCONTROL +kALT:
		NDir->cd("v:\\");
		reloadtab();
		break;
	case 'W' +kCONTROL +kALT:
		NDir->cd("w:\\");
		reloadtab();
		break;
	case 'X' +kCONTROL +kALT:
		NDir->cd("x:\\");
		reloadtab();
		break;
	case 'Y' +kCONTROL +kALT:
		NDir->cd("y:\\");
		reloadtab();
		break;
	case 'Z' +kCONTROL +kALT:
		NDir->cd("z:\\");
		reloadtab();
		break;
	case VK_HOME +kALT:
		mainMsg( IDM_LOAD_WINS_HOME);
		break;
	case VK_HOME +kALT +kSHIFT:
		mainMsg( IDM_SAVE_WINS_HOME);
		break;
	case 'A' +kCONTROL:
		mainMsg( IDM_REV_SELECT);
		break;
	case 'B' +kCONTROL:
		mainMsg( IDM_UP_BUTTON);
		break;
	case 'C' +kCONTROL:
		msgCpy();
		break;
	case 'D' +kCONTROL:
		msgDel();
		break;
	case 'E' +kCONTROL:
		msgEdit();
		break;
	case 'E' +kSHIFT +kCONTROL:
		mainMsg( IDM_EDIT_INIT );
		break;
	case 'F' +kCONTROL:
		mainMsg( IDM_FIND );
		break;
	case 'F' +kSHIFT +kCONTROL:
		mainMsg( IDM_FIND2 );//mainMsg( IDM_FIND_MORE );
		break;
	case 'G' +kCONTROL:
		mainMsg(IDM_COM);
		break;
	case 'G' +kSHIFT +kCONTROL:
		mainMsg(IDM_COM_NUM);
		break;
	case 'M' +kCONTROL:
		TrackPopupMenu(hSendtoMenu, TPM_LEFTALIGN | TPM_TOPALIGN,
                    0,0, 0, hWnd, NULL);
		break;
	case 'L' +kCONTROL:
		TrackPopupMenu(hBothMenu, TPM_LEFTALIGN | TPM_TOPALIGN,
                    0,0, 0, hWnd, NULL);
		break;
	case 'N' +kCONTROL:
		mainMsg( IDM_NEW_FILE );
		break;
	case 'N' +kSHIFT +kCONTROL:
		mainMsg( IDM_LOCAL_CREATE_FILE );
		break;
	case 'O' +kCONTROL://I[
		mainMsg(IDM_SameDir);
		break;
	case 'O' +kSHIFT +kCONTROL://I[
		mainMsg(IDM_SSameDir);
		break;
	case 'P' +kSHIFT:
		mainMsg(IDM_ZIP);
		break;
	case 'P' +kCONTROL:
		mainMsg(IDM_EXT_SETCOLOR);
		break;
	case 'P' +kCONTROL +kSHIFT:
		mainMsg(IDM_EXT_SETCOLOR_THIS);
		break;
	case 'Q' +kCONTROL:
		msgQuit();
		break;
	case 'R' +kSHIFT +kCONTROL:
		reloadbothdir();
		break;
	case 'R' +kCONTROL:
		mainMsg(IDM_RENAME);
		break;
	case 'S' +kCONTROL:
		mainMsg(IDM_SAVE_DIRLOCAL);
		break;
	case 'S' +kSHIFT +kCONTROL:
		mainMsg(IDM_SAVE_WINS);
		break;
	case 'W' +kCONTROL:
		mainMsg(IDM_COMPARE);
		break;
	case 'X' +kCONTROL:
		mainMsg(IDM_EXCHANGE);
		break;
	case 'X' +kSHIFT +kCONTROL:
		mainMsg(IDM_OPEN_CUR);
		break;
	case 'X' +kSHIFT +kALT +kCONTROL:
		mainMsg(IDM_OPEN_INI);
		break;
	case 'Z' +kCONTROL:
		mainMsg(IDM_EDIT_INIT);
		break;
	case '0' +kCONTROL://[
		msgDrive();
		break;
	case VK_ADD +kCONTROL:
		mainMsg(IDM_LISTL_WIDTH_1);
		break;
	case VK_DIVIDE +kCONTROL:
		mainMsg(IDM_LISTL_WIDTH_2);
		break;
	case VK_SUBTRACT +kCONTROL:
		mainMsg(IDM_LISTL_WIDTH_3);
		break;
	case VK_ADD +kALT:
		mainMsg(IDM_WINDOW_BIGGER);
		break;
	case VK_SUBTRACT +kALT:
		mainMsg(IDM_WINDOW_SMALLER);
		break;
	case '1' +kCONTROL +kALT:
		mainMsg(IDM_SORT1);
		break;
	case '2' +kCONTROL +kALT:
		mainMsg(IDM_SORT2);
		break;
	case '3' +kCONTROL +kALT:
		mainMsg(IDM_SORT3);
		break;
	case '4' +kCONTROL +kALT:
		mainMsg(IDM_SORT4);
		break;
	case '5' +kCONTROL +kALT:
		mainMsg(IDM_SORT5);
		break;
	case '1' +kCONTROL:
		mainMsg(IDM_LISTL_ONLY);
		break;
	case '2' +kCONTROL:
		mainMsg(IDM_LISTR_ONLY);
		break;
	case VK_DOWN +kCONTROL +kALT:
		msgWinmode();
		break;
	case 220: //"\\"
		msgRoot();
		break;
	default:
		break;
	}
}

==> filemv0.378.1.zip: source/keyboard.cpp <==

#ifndef STRICT
    #define STRICT
#endif
#include "defextern.h"
#include <windows.h>
#include <windowsx.h>
#include <commctrl.h>
#include "resource.h"
#include "dir.h"
#include "myfilemv.h"
#include "initial.h"
#include "keyboard.h"
#include "main.h"


#include "mainmsg.h"



WORD keyfnc(WORD key)
{
	WORD al =0;
	if (GetKeyState(VK_SHIFT) < 0) al += kSHIFT;
	if (GetKeyState(VK_CONTROL) < 0) al += kCONTROL;
	if (GetKeyState(VK_MENU) < 0) al += kALT;
	return transkey( key + al );
}



#define kCASE(a,b) case a :{ mainMsg(b) ; break; }


// tH[JXXgɂƂ̃L[

void ListKeyFunc(HWND hWnd, UINT msg, WPARAM wp, LPARAM lp,int tab)
{
    static LPNMHDR lpnmhdr;
    static LV_KEYDOWN *lvkeydown;
	dirw *NDir =GetNDir();
    lpnmhdr = (LPNMHDR)lp;
	lvkeydown =(LV_KEYDOWN*)lp;//EN_UPDATE
	WORD key =keyfnc(lvkeydown->wVKey);

	// R}h
	if(key >= '1'+kALT && key <= '9' +kALT)
		mainMsg( IDM_CMD_BASE + (key - ('1'+kALT) +1 ) );
	switch (key)
	{
	case VK_ESCAPE :
		{
			SetFocus(hEdit);
			return ;
		}
	case VK_RETURN +kSHIFT: 
		mainMsg( IDM_EDIT );
		break;
	case VK_RETURN: 
		lpnmhdr->code =NM_DBLCLK;
		SendMessage( hWnd, msg, wp, lp);
		break;
	case VK_F11: 
		mainMsg( IDM_WINDOW_MAX);
		break;
	case VK_F11 +kSHIFT: 
		mainMsg( IDM_WINDOW_INI);
		break;
	case VK_TAB: 
		if(tab ==tab_l ) SetFocus(hList);
		if(tab ==tab_r ) SetFocus(hListL);
		break;
	case VK_BACK:
		mainMsg( IDM_UPDIRLOCAL);
		break;
	case VK_DELETE:
		mainMsg( IDM_DELFILELOCAL);
		break;
	case VK_DELETE +kSHIFT:
		mainMsg( IDM_DEL_MENU);
		break;
	case VK_LEFT +kSHIFT:
		mainMsg( IDM_HIS_BACKWARD);
		break;
	case VK_RIGHT +kSHIFT:
		mainMsg( IDM_HIS_FORWARD);
		break;
	case VK_LEFT +kALT:
		break;
	case VK_RIGHT +kALT:
		break;
	case 'A' +kCONTROL +kALT:
		NDir->cd("a:\\");
		reloadtab();
		break;
	case 'B' +kCONTROL +kALT:
		NDir->cd("b:\\");
		reloadtab();
		break;
	case 'C' +kCONTROL +kALT:
		NDir->cd("c:\\");
		reloadtab();
		break;
	case 'D' +kCONTROL +kALT:
		NDir->cd("d:\\");
		reloadtab();
		break;
	case 'E' +kCONTROL +kALT:
		NDir->cd("e:\\");
		reloadtab();
		break;
	case 'F' +kCONTROL +kALT:
		NDir->cd("f:\\");
		reloadtab();
		break;
	case 'G' +kCONTROL +kALT:
		NDir->cd("g:\\");
		reloadtab();
		break;
	case 'H' +kCONTROL +kALT:
		NDir->cd("h:\\");
		reloadtab();
		break;
	case 'I' +kCONTROL +kALT:
		NDir->cd("i:\\");
		reloadtab();
		break;
	case 'J' +kCONTROL +kALT:
		NDir->cd("j:\\");
		reloadtab();
		break;
	case 'K' +kCONTROL +kALT:
		NDir->cd("k:\\");
		reloadtab();
		break;
	case 'L' +kCONTROL +kALT:
		NDir->cd("l:\\");
		reloadtab();
		break;
	case 'M' +kCONTROL +kALT:
		NDir->cd("m:\\");
		reloadtab();
		break;
	case 'N' +kCONTROL +kALT:
		NDir->cd("n:\\");
		reloadtab();
		break;
	case 'O' +kCONTROL +kALT:
		NDir->cd("o:\\");
		reloadtab();
		break;
	case 'P' +kCONTROL +kALT:
		NDir->cd("p:\\");
		reloadtab();
		break;
	case 'Q' +kCONTROL +kALT:
		NDir->cd("q:\\");
		reloadtab();
		break;
	case 'R' +kCONTROL +kALT:
		NDir->cd("r:\\");
		reloadtab();
		break;
	case 'S' +kCONTROL +kALT:
		NDir->cd("s:\\");
		reloadtab();
		break;
	case 'T' +kCONTROL +kALT:
		NDir->cd("t:\\");
		reloadtab();
		break;
	case 'U' +kCONTROL +kALT:
		NDir->cd("u:\\");
		reloadtab();
		break;
	case 'V' +kCONTROL +kALT:
		NDir->cd("v:\\");
		reloadtab();
		break;
	case 'W' +kCONTROL +kALT:
		NDir->cd("w:\\");
		reloadtab();
		break;
	case 'X' +kCONTROL +kALT:
		NDir->cd("x:\\");
		reloadtab();
		break;
	case 'Y' +kCONTROL +kALT:
		NDir->cd("y:\\");
		reloadtab();
		break;
	case 'Z' +kCONTROL +kALT:
		NDir->cd("z:\\");
		reloadtab();
		break;
	case VK_HOME +kALT:
		mainMsg( IDM_LOAD_WINS_HOME);
		break;
	case VK_HOME +kALT +kSHIFT:
		mainMsg( IDM_SAVE_WINS_HOME);
		break;
	case 'A' +kCONTROL:
		mainMsg( IDM_REV_SELECT);
		break;
	case 'B' +kCONTROL:
		mainMsg( IDM_UP_BUTTON);
		break;
	case 'C' +kCONTROL:
		msgCpy();
		break;
	case 'D' +kCONTROL:
		msgDel();
		break;
	case 'E' +kCONTROL:
		msgEdit();
		break;
	case 'E' +kSHIFT +kCONTROL:
		//mainMsg( IDM_EDIT_INIT );
		break;
	case 'F' +kCONTROL:
		mainMsg( IDM_FIND );
		break;
	case 'F' +kSHIFT +kCONTROL:
		mainMsg( IDM_FIND2 );//mainMsg( IDM_FIND_MORE );
		break;
	case 'G' +kCONTROL:
		mainMsg(IDM_COM);
		break;
	case 'G' +kSHIFT +kCONTROL:
		mainMsg(IDM_COM_NUM);
		break;
	case 'M' +kCONTROL:
		TrackPopupMenu(hSendtoMenu, TPM_LEFTALIGN | TPM_TOPALIGN,
                    0,0, 0, hWnd, NULL);
		break;
	case 'L' +kCONTROL:
		TrackPopupMenu(hBothMenu, TPM_LEFTALIGN | TPM_TOPALIGN,
                    0,0, 0, hWnd, NULL);
		break;
	case 'N' +kCONTROL:
		mainMsg( IDM_NEW_FILE );
		break;
	case 'N' +kSHIFT +kCONTROL:
		mainMsg( IDM_LOCAL_CREATE_FILE );
		break;
	case 'O' +kCONTROL://I[
		mainMsg(IDM_SameDir);
		break;
	case 'O' +kSHIFT +kCONTROL://I[
		mainMsg(IDM_SSameDir);
		break;
	case 'P' +kSHIFT:
		mainMsg(IDM_ZIP);
		break;
	case 'P' +kCONTROL:
		mainMsg(IDM_EXT_SETCOLOR);
		break;
	case 'P' +kCONTROL +kSHIFT:
		mainMsg(IDM_EXT_SETCOLOR_THIS);
		break;
	case 'Q' +kCONTROL:
		msgQuit();
		break;
	case 'R' +kSHIFT +kCONTROL:
		reloadbothdir();
		break;
	case 'R' +kCONTROL:
		mainMsg(IDM_RENAME);
		break;
	case 'S' +kCONTROL:
		mainMsg(IDM_SAVE_DIRLOCAL);
		break;
	case 'S' +kSHIFT +kCONTROL:
		mainMsg(IDM_SAVE_WINS);
		break;
	case 'W' +kCONTROL:
		mainMsg(IDM_COMPARE);
		break;
	case 'X' +kCONTROL:
		mainMsg(IDM_EXCHANGE);
		break;
	case 'X' +kSHIFT +kCONTROL:
		mainMsg(IDM_OPEN_CUR);
		break;
	case 'X' +kSHIFT +kALT +kCONTROL:
		mainMsg(IDM_OPEN_INI);
		break;
	case 'Z' +kCONTROL:
		mainMsg(IDM_EDIT_INIT);
		break;
	case 'Z' +kSHIFT +kCONTROL:
		mainMsg( IDM_OPEN_KEY_FILE );
		break;
	case '0' +kCONTROL://[
		msgDrive();
		break;
	case VK_ADD +kCONTROL:
		mainMsg(IDM_LISTL_WIDTH_1);
		break;
	case VK_DIVIDE +kCONTROL:
		mainMsg(IDM_LISTL_WIDTH_2);
		break;
	case VK_SUBTRACT +kCONTROL:
		mainMsg(IDM_LISTL_WIDTH_3);
		break;
	case VK_ADD +kALT:
		mainMsg(IDM_WINDOW_BIGGER);
		break;
	case VK_SUBTRACT +kALT:
		mainMsg(IDM_WINDOW_SMALLER);
		break;
	case '1' +kCONTROL +kALT:
		mainMsg(IDM_SORT1);
		break;
	case '2' +kCONTROL +kALT:
		mainMsg(IDM_SORT2);
		break;
	case '3' +kCONTROL +kALT:
		mainMsg(IDM_SORT3);
		break;
	case '4' +kCONTROL +kALT:
		mainMsg(IDM_SORT4);
		break;
	case '5' +kCONTROL +kALT:
		mainMsg(IDM_SORT5);
		break;
	case '1' +kCONTROL:
		mainMsg(IDM_LISTL_ONLY);
		break;
	case '2' +kCONTROL:
		mainMsg(IDM_LISTR_ONLY);
		break;
	case VK_DOWN +kCONTROL +kALT:
		msgWinmode();
		break;
	case 220: //"\\"
		msgRoot();
		break;
	default:
		break;
	}
}
